@@ -680,7 +680,7 @@ public class NotifyLogEscalateCreateDialog extends NotifyBasicCreateDialog {
         info.setNotifyType(m_notifyType);
         
         // 通知基本情報
-        validateResult = super.m_notifyBasic.createInputData(info);
+        validateResult = super.m_notifyBasic.createInputData(info, this.notifyId);
         if(validateResult != null){
         	return null;
         }
