@@ -36,11 +36,12 @@ import org.apache.commons.logging.LogFactory;
 import com.clustercontrol.commons.util.ConnectionManager;
 import com.clustercontrol.jobmanagement.ejb.entity.JobNoticeInfoBean;
 import com.clustercontrol.jobmanagement.ejb.entity.JobNoticeInfoPK;
+import com.clustercontrol.notify.bean.NotifyRelationInfo;
 
 /**
  * ジョブ通知情報のDAOインターフェースを実装するクラス<BR>
  * 
- * @version 2.1.0
+ * @version 3.0.0
  * @since 2.1.0
  * 
  * @see com.clustercontrol.jobmanagement.ejb.entity.JobNoticeInfoBean
@@ -85,7 +86,7 @@ public class JobNoticeInfoDAOImpl implements JobNoticeInfoDAO {
 				//取得した値をBeanにセット
 				ejb.setJob_id(res.getString("job_id"));
 				ejb.setNotice_type(res.getInt("notice_type"));
-				ejb.setNotify_id(res.getString("notify_id"));
+				ejb.setNotifyGroupId(res.getString("notify_group_id"));
 				ejb.setPriority(res.getInt("priority"));
 				ejb.setSession_id(res.getString("session_id"));
 			} else {
@@ -134,7 +135,7 @@ public class JobNoticeInfoDAOImpl implements JobNoticeInfoDAO {
 			StringBuilder sql = new StringBuilder();
 			sql.append("UPDATE cc_job_notice_info SET ");
 			sql.append("priority = ?, ");
-			sql.append("notify_id = ? ");
+			sql.append("notify_group_id = ? ");
 			sql.append("WHERE session_id = ? AND ");
 			sql.append("job_id = ? AND ");
 			sql.append("notice_type = ?");
@@ -143,7 +144,7 @@ public class JobNoticeInfoDAOImpl implements JobNoticeInfoDAO {
 			stmt = conn.prepareStatement(sql.toString());
 			
 			stmt.setInt(1, ejb.getPriority());
-			stmt.setString(2, ejb.getNotify_id());
+			stmt.setString(2, ejb.getNotifyGroupId());
 			stmt.setString(3, ejb.getSession_id());
 			stmt.setString(4, ejb.getJob_id());
 			stmt.setInt(5, ejb.getNotice_type());
@@ -249,7 +250,7 @@ public class JobNoticeInfoDAOImpl implements JobNoticeInfoDAO {
 			sql.append("job_id, ");
 			sql.append("notice_type, ");
 			sql.append("priority, ");
-			sql.append("notify_id) ");
+			sql.append("notify_group_id) ");
 			sql.append("VALUES (?,?,?,?,?)");
 			
 			//SQL文のセット
@@ -259,7 +260,7 @@ public class JobNoticeInfoDAOImpl implements JobNoticeInfoDAO {
 			stmt.setString(2, ejb.getJob_id());
 			stmt.setInt(3, ejb.getNotice_type());
 			stmt.setInt(4, ejb.getPriority());
-			stmt.setString(5, ejb.getNotify_id());
+			stmt.setString(5, ejb.getNotifyGroupId());
 			
 			int row =	stmt.executeUpdate();
 			pk = new JobNoticeInfoPK(
@@ -466,6 +467,7 @@ public class JobNoticeInfoDAOImpl implements JobNoticeInfoDAO {
 	 * 
 	 * @param sessionId セッションID
 	 * @param jobs ジョブIDのコレクション
+	 * @param notifyGroupIdSession JobNoticeInfo用の通知グループID
 	 * @throws CreateException
 	 * 
 	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobNoticeInfoBean#ejbHomeMakeSession(String, Collection)
@@ -478,6 +480,7 @@ public class JobNoticeInfoDAOImpl implements JobNoticeInfoDAO {
 		PreparedStatement stmt = null;
 		PreparedStatement stmtMaster = null;
 		String jobId = null;
+		String infoNotifyGroupId = null;	//JobNoticeInfo用の通知グループID
 		
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();
@@ -490,7 +493,7 @@ public class JobNoticeInfoDAOImpl implements JobNoticeInfoDAO {
 			sql.append("job_id, ");
 			sql.append("notice_type, ");
 			sql.append("priority, ");
-			sql.append("notify_id) ");
+			sql.append("notify_group_id) ");
 			sql.append("VALUES (?,?,?,?,?)");
 			
 			//SQLのセット(INSERT)
@@ -508,6 +511,9 @@ public class JobNoticeInfoDAOImpl implements JobNoticeInfoDAO {
 				Hashtable ht = (Hashtable)it.next();
 				jobId = (String)ht.get("jobId");
 				
+				//JobNoticeInfo用の通知グループID
+				infoNotifyGroupId = NotifyRelationInfo.createNotifyGroupIdJobInfo(sessionId, jobId, 0);
+				
 				//SQLのセット(マスタ検索)
 				stmtMaster.setString(1, jobId);
 				//SQL実行(マスタ検索)
@@ -518,7 +524,7 @@ public class JobNoticeInfoDAOImpl implements JobNoticeInfoDAO {
 					stmt.setString(2, jobId);
 					stmt.setInt(3, resMaster.getInt("notice_type"));
 					stmt.setInt(4, resMaster.getInt("priority"));
-					stmt.setString(5, resMaster.getString("notify_id"));
+					stmt.setString(5, infoNotifyGroupId);
 					//INSERTを実行
 					int row =	stmt.executeUpdate();
 					if (row != 1) {
