@@ -799,16 +799,17 @@ public class JobSessionNodeDAOImpl implements JobSessionNodeDAO {
 						updateStmt.close();
 						
 						//ノードのファシリティIDリスト取得
-						ArrayList<String> nodeIdList = null;
-						if(repository.isNode(facilityId)){
-							//ファシリティIDがノードの場合
-							nodeIdList = new ArrayList<String>();
-							nodeIdList.add(facilityId);
-						}
-						else{
-							//ファシリティIDがスコープの場合
-							nodeIdList = repository.getNodeFacilityIdList(facilityId, RepositoryControllerBean.ALL);
-						}
+						ArrayList<String> nodeIdList = repository.getExecTargetFacilityIdList(facilityId);
+//						ArrayList<String> nodeIdList = null;
+//						if(repository.isNode(facilityId)){
+//							//ファシリティIDがノードの場合
+//							nodeIdList = new ArrayList<String>();
+//							nodeIdList.add(facilityId);
+//						}
+//						else{
+//							//ファシリティIDがスコープの場合
+//							nodeIdList = repository.getNodeFacilityIdList(facilityId, RepositoryControllerBean.ALL);
+//						}
 						
 						if(nodeIdList instanceof ArrayList){
 							for(int i = 0; i < nodeIdList.size(); i++){
