@@ -250,7 +250,8 @@ public class ParameterUtil {
 		int ret = 0;
 		
 		// ジョブ関連
-		if (paramId.equals(SystemParameterConstant.SESSION_ID)
+		if (paramId.equals(SystemParameterConstant.START_DATE)
+				|| paramId.equals(SystemParameterConstant.SESSION_ID)
 				|| paramId.equals(SystemParameterConstant.TRIGGER_TYPE)
 				|| paramId.equals(SystemParameterConstant.TRIGGER_INFO )){
 			
