@@ -28,11 +28,11 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.bean.ConfirmConstant;
+import com.clustercontrol.bean.OutputNotifyGroupInfo;
 import com.clustercontrol.bean.ValidConstant;
 import com.clustercontrol.bean.YesNoConstant;
 import com.clustercontrol.logagent.util.EjbConnectionManager;
 import com.clustercontrol.logtransfer.bean.LogTransferFileInfo;
-import com.clustercontrol.monitor.message.LogOutputInfo;
 import com.clustercontrol.repository.ejb.session.RepositoryController;
 
 
@@ -41,7 +41,7 @@ import com.clustercontrol.repository.ejb.session.RepositoryController;
  * 
  * 転送対象ログファイル情報を受け取り、ログ転送スレッドを制御します。
  *  
- * @version 2.1.0
+ * @version 3.0.0
  * @since 2.1.0
  */
 public class TransferLogManager {
@@ -276,6 +276,7 @@ public class TransferLogManager {
 			//すべての設定情報がなければ
 			if(info.size() == 0){
 				//ログ停止
+				log.debug("thread stop : file path : " + logName);
 				thread.requestStop();
 				//転送情報も削除
 				m_runTransferLog.remove(logName);
@@ -323,6 +324,7 @@ public class TransferLogManager {
 						logInfo.getTransferId().equals(logInfoFacility.getTransferId()) )
 					{
 						//ログ情報の削除
+						log.debug("remove " + logInfoFacility.getFilePath() + " : " + logInfoFacility.getTransferId());
 						logMnginfo.remove(logInfoFacility);
 						
 					}else{
@@ -346,6 +348,7 @@ public class TransferLogManager {
 				//すべての設定情報がなければ
 				if(logMnginfo.size() == 0){
 					//ログ停止
+					log.debug("thread stop : file path : " + filePath);
 					thread.requestStop();
 					//転送情報も削除
 					m_runTransferLog.remove(filePath);
@@ -516,30 +519,105 @@ public class TransferLogManager {
 		}
 
 		// ログ出力情報
-		LogOutputInfo logOutput = new LogOutputInfo();
-		logOutput.setPluginId(Agent.PLUGIN_ID);
-		logOutput.setPriority(priority);
-		logOutput.setApplication(app);
-		logOutput.setMessageId(msgId);
-		logOutput.setMessage(msg);
-		logOutput.setMessageOrg(msgOrg);
-		logOutput.setConfirmFlg(ConfirmConstant.TYPE_UNCONFIRMED);
-		logOutput.setGenerationDate(new Date());
-		logOutput.setEventLogFlg(true);
-		logOutput.setStatusInfoFlg(false);
+		OutputNotifyGroupInfo output = new OutputNotifyGroupInfo();
+		output.setPluginId(Agent.PLUGIN_ID);
+		output.setPriority(priority);
+		output.setApplication(app);
+		output.setMessageId(msgId);
+		output.setMessage(msg);
+		output.setMessageOrg(msgOrg);
+		output.setGenerationDate(new Date());
 		
 		for (Iterator iter = info.iterator(); iter.hasNext();) {
 			LogTransferFileInfoFacility logInfo = (LogTransferFileInfoFacility) iter.next();
 			
-			logOutput.setMonitorId(logInfo.getTransferId());
-			logOutput.setFacilityId(logInfo.getFacilityId());
-			logOutput.setScopeText(logInfo.getFacilityPath());	
+			output.setMonitorId(logInfo.getTransferId());
+			output.setFacilityId(logInfo.getFacilityId());
+			output.setScopeText(logInfo.getFacilityPath());	
 
-			this.m_sendQueue.put(logOutput);			
+			this.m_sendQueue.put(output);			
 			
 		}
 		
 	}
-	
 
+
+	/**
+	 * ログ転送情報をリフレッシュする
+	 * 起動時、再接続時にマネージャから送られてくるファイルリスト情報と
+	 * キャッシュ上のファイルリスト情報を比較し、存在しないものがある場合は、
+	 * キャッシュ上のファイルリストから削除する。
+	 * 
+	 * @param facilityId マネージャから送られてきたファシリティID
+	 * @param logList マネージャから送られてきたファイル情報
+	 */
+	public void refreshRunTransferLog(String facilityId, ArrayList<LogTransferFileInfo> logList) {
+		
+		Set keySet = new HashSet<String>(m_runTransferLog.keySet());
+		
+		if(keySet != null && keySet.size() > 0) {
+		
+			for (Iterator itr = keySet.iterator(); itr.hasNext();) {
+				
+				String filePath = (String) itr.next();
+				
+				// ファイルパスを基に、LogThreadManagerInfoを取得
+				LogThreadManageInfo info = m_runTransferLog.get(filePath);
+				if(info == null){
+					continue;
+				}
+				
+				// ファイルパスが同じ内容の物が複数ある場合
+				for(Iterator itr2 = info.iterator(); itr2.hasNext();) {
+					LogTransferFileInfoFacility logFileInfoCache = (LogTransferFileInfoFacility)itr2.next();
+										
+					// キャッシュ上のファイル情報のファシリティIDと引数のファシリティIDを確認し、
+					// 同じ場合のみ処理を続ける。
+					if (!logFileInfoCache.getFacilityId().equals(facilityId)){
+						continue;
+					}
+					
+					boolean checkFlg = true;
+					
+					// 新しく取得したログ転送情報と既にHashtableに載っている情報の転送設定IDとファイルパスを比較し、
+					// どちらか存在しないものがあれば、そのThreadを停止する。
+					for(Iterator itr3 = logList.iterator(); itr3.hasNext();) {
+						LogTransferFileInfo logFileInfoNew = (LogTransferFileInfo)itr3.next();
+						
+						// 転送設定IDを比較
+						if(logFileInfoCache.getTransferId().equals(logFileInfoNew.getTransferId())){
+							//ファイルパスを比較
+							if(logFileInfoCache.getFilePath().equals(logFileInfoNew.getFilePath())){
+								log.debug("match : transferID : "+logFileInfoCache.getTransferId()+
+										" file path : "+logFileInfoCache.getFilePath()+
+										" facilityID : "+logFileInfoCache.getFacilityId());
+								checkFlg = false;
+								break;
+							}
+						}
+					}
+					
+					// 転送設定IDとファイルパスのどちらかが異なっていた場合、キャッシュ上から削除する
+					if(checkFlg) {
+						log.debug("remove : transferID : "+logFileInfoCache.getTransferId()+
+								" file path : "+logFileInfoCache.getFilePath()+
+								" facilityID : "+logFileInfoCache.getFacilityId());
+						info.remove(logFileInfoCache);
+						
+						TransferLogThread thread = info.getThread();
+
+						//すべての設定情報がなければ
+						if(info.size() == 0){
+							//ログ停止
+							log.debug("thread stop : file path : " + filePath);
+							thread.requestStop();
+							//転送情報も削除
+							m_runTransferLog.remove(filePath);
+						}						
+					}				
+				}
+			}
+		}
+	}
+	
 }
