@@ -645,6 +645,8 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
 	public void modifyConfirm(String monitorId,
 			String pluginId,
 			String facilityId,
+			int priority,
+			Date generateDate,
 			Date outputDate,
 			Date confirmDate,
 			int confirmType
@@ -654,7 +656,7 @@ public abstract class MonitorControllerBean implements javax.ejb.SessionBean {
 				
 		// イベントの確認状態を更新する
 		ModifyEventConfirm modify = new ModifyEventConfirm();
-		modify.modifyConfirm(monitorId, pluginId, facilityId, outputDate, confirmDate, confirmType, confirmUser);
+		modify.modifyConfirm(monitorId, pluginId, facilityId, priority, generateDate, outputDate, confirmDate, confirmType, confirmUser);
 	}
 	
 	/**
