@@ -15,12 +15,15 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.monitor.factory;
 
+import java.io.File;
+import java.io.FileInputStream;
 import java.sql.SQLException;
 import java.sql.Timestamp;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Date;
 import java.util.Iterator;
+import java.util.Properties;
 
 import javax.ejb.CreateException;
 import javax.ejb.FinderException;
@@ -61,6 +64,49 @@ public class SelectEvent {
 	 */
 	private final static int MAX_DISPLAY_NUMBER = 500;
 	
+	/**
+	 * ダウンロード可能な最大イベント数
+	 * CSVおよびPDFで出力される最大のイベント数を格納します。
+	 */
+	private static Integer MAX_REPORT_EVENT_COUNT = null;
+	private static Integer MAX_REPORT_EVENT_COUNT_DEFAULT = 1000; 
+	
+	
+	
+	/**
+	 * コンストラクタ
+	 * 各種設定値を格納します
+	 */
+	public SelectEvent() {
+		if (MAX_REPORT_EVENT_COUNT == null) {
+			Properties properties = new Properties();
+			
+			try {
+				String etcdir = System.getProperty("hinemos.manager.etc.dir");
+				String propertyFile = etcdir + File.separator + "hinemos.properties";
+				
+				// プロパティファイルからキーと値のリストを読み込みます
+				properties.load(new FileInputStream(propertyFile));
+				
+				// ダウンロード可能な最大イベント数を取得
+				if (properties.containsKey("monitor.common.report.event.count")) {
+					MAX_REPORT_EVENT_COUNT = Integer.parseInt(properties.getProperty("monitor.common.report.event.count"));
+				} else {
+					MAX_REPORT_EVENT_COUNT = MAX_REPORT_EVENT_COUNT_DEFAULT;
+				}
+			} catch (Exception e) {
+				MAX_REPORT_EVENT_COUNT = MAX_REPORT_EVENT_COUNT_DEFAULT;
+			} finally {
+				if (MAX_REPORT_EVENT_COUNT < -1) {
+					MAX_REPORT_EVENT_COUNT = MAX_REPORT_EVENT_COUNT_DEFAULT;
+				} else if (MAX_REPORT_EVENT_COUNT == -1) {
+					MAX_REPORT_EVENT_COUNT = null;
+				}
+				
+			}
+		}
+	}
+	
 	/**
 	 * イベント一覧情報を返します。<BR>
 	 * 表示イベント数を越えた場合は、表示イベント数分のイベント情報一覧を返します。
@@ -776,7 +822,7 @@ public class SelectEvent {
 					confirmFlg,
 					confirmUser, 
 					true,
-					null);
+					MAX_REPORT_EVENT_COUNT);
 			
 //			// 取得したイベントが最大表示件数より大きい場合、エラーを発生させる
 //			if(m_eventMaxDisplayNumber != -1 && ct.size() > m_eventMaxDisplayNumber){
