@@ -28,6 +28,7 @@ import javax.naming.NamingException;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.NotifyTypeConstant;
 import com.clustercontrol.bean.ValidConstant;
 import com.clustercontrol.bean.YesNoConstant;
@@ -38,6 +39,7 @@ import com.clustercontrol.notify.bean.NotifyJobInfo;
 import com.clustercontrol.notify.bean.NotifyLogEscalateInfo;
 import com.clustercontrol.notify.bean.NotifyMailInfo;
 import com.clustercontrol.notify.bean.NotifyStatusInfo;
+import com.clustercontrol.notify.bean.NotifyUseTyperConstant;
 import com.clustercontrol.notify.ejb.entity.NotifyEventInfoLocal;
 import com.clustercontrol.notify.ejb.entity.NotifyInfoLocal;
 import com.clustercontrol.notify.ejb.entity.NotifyInfoUtil;
@@ -288,7 +290,7 @@ public class SelectNotify {
 	}
 
 	/**
-	 * 通知情報一覧を返します。
+	 * 通知情報一覧を返します(障害検知用通知を除く)。
 	 * <p>
 	 * <ol>
 	 * <li>通知IDの昇順に並んだ全ての通知情報を取得します。</li>
@@ -309,16 +311,35 @@ public class SelectNotify {
 	 * @see com.clustercontrol.notify.bean.NotifyTableDefine
 	 * @see #collectionToArray(Collection)
 	 */
-	public ArrayList getNotifyList() throws CreateException, FinderException, NamingException {
+	public ArrayList<NotifyInfoLocal> getNotifyList() throws CreateException, FinderException, NamingException {
 
-		ArrayList list = null;
+		ArrayList<NotifyInfoLocal> list = null;
 		try 
 		{
 			// 通知情報一覧を取得
-			Collection ct = NotifyInfoUtil.getLocalHome().findAllOrderByNotifyId();
+			Collection<NotifyInfoLocal> ct = NotifyInfoUtil.getLocalHome().findAllOrderByNotifyId();
+			Collection<NotifyInfoLocal> retct = NotifyInfoUtil.getLocalHome().findAllOrderByNotifyId();
+			
+			if(ct.size() != 0) {
+				
+				Iterator<NotifyInfoLocal> itr = ct.iterator();
+				
+				// 障害検知用の通知IDを除く
+				while(itr.hasNext()){
+					
+					NotifyInfoLocal notify = itr.next();
+					String regex = "^" + HinemosModuleConstant.SYSYTEM_TROUBLE_DETECTION + ".*";
+					
+					// FIXME : 文字列の比較による障害検知用通知IDの特定方法を変更する
+					// 結果用Collectionから削除対象のCollectionを削除する
+					if(notify.getNotifyId().matches(regex)){
+						retct.remove(notify);
+					}
+				}
+			}
 			
 			// 2次元配列に変換
-			list = this.collectionToArray(ct);
+			list = this.collectionToArray(retct);
 			
 		} catch (CreateException e) {
 			AplLogger apllog = new AplLogger("NOTIFY", "notify");
@@ -391,6 +412,129 @@ public class SelectNotify {
 		return map;
 	}
 
+	/**
+	 * 障害検知用通知情報一覧を返します。
+	 * <p>
+	 * <ol>
+	 * <li>通知IDの昇順に並んだ全ての通知情報を取得します。</li>
+	 * <li>１通知情報をテーブルのカラム順（{@link com.clustercontrol.notify.bean.NotifyTableDefine}）に、リスト（{@link ArrayList}）にセットします。</li>
+	 * <li>この１通知情報を保持するリストを、通知情報一覧を保持するリスト（{@link ArrayList}）に格納し返します。<BR>
+	 *  <dl>
+	 *  <dt>通知情報一覧（Objectの2次元配列）</dt>
+	 *  <dd>{ 通知情報1 {カラム1の値, カラム2の値, … }, 通知情報2{カラム1の値, カラム2の値, …}, … }</dd>
+	 *  </dl>
+	 * </li>
+	 * </ol>
+	 * 
+	 * @return 通知情報一覧（Objectの2次元配列）
+	 * @throws CreateException
+	 * @throws FinderException
+	 * @throws NamingException
+	 * 
+	 * @see com.clustercontrol.notify.bean.NotifyTableDefine
+	 * @see #collectionToArray(Collection)
+	 */
+	public ArrayList<NotifyInfoLocal> getTroubleDetectionNotifyList() throws CreateException, FinderException, NamingException {
+
+		ArrayList<NotifyInfoLocal> list = null;
+		try 
+		{
+			// 通知情報一覧を取得
+			Collection<NotifyInfoLocal> ct = NotifyInfoUtil.getLocalHome().findAllOrderByNotifyId();
+			Collection<NotifyInfoLocal> retct = NotifyInfoUtil.getLocalHome().findAllOrderByNotifyId();
+			
+			if(ct.size() != 0) {
+			
+				Iterator<NotifyInfoLocal> itr = ct.iterator();
+				
+				// 障害検知用の通知IDのみを取得
+				while(itr.hasNext()){
+					
+					NotifyInfoLocal notify = itr.next();
+					String regex = "^" + HinemosModuleConstant.SYSYTEM_TROUBLE_DETECTION + ".*";
+					
+					// FIXME : 文字列の比較による障害検知用通知IDの特定方法を変更する
+					// 結果用Collectionから削除対象のCollectionを削除する
+					if(!notify.getNotifyId().matches(regex)){
+						retct.remove(notify);
+					}
+				}
+			}
+			
+			// 2次元配列に変換
+			list = this.collectionToArray(retct);
+			
+		} catch (CreateException e) {
+			AplLogger apllog = new AplLogger("NOTIFY", "notify");
+            apllog.put("SYS", "006");
+            m_log.debug("getNotifyList():" + e.getMessage());
+			throw e;
+		} catch (FinderException e) {
+			AplLogger apllog = new AplLogger("NOTIFY", "notify");
+            apllog.put("SYS", "006");
+            m_log.debug("getNotifyList():" + e.getMessage());
+			throw e;
+		} catch (NamingException e) {
+			AplLogger apllog = new AplLogger("NOTIFY", "notify");
+            apllog.put("SYS", "006");
+            m_log.debug("getNotifyList():" + e.getMessage());
+			throw e;
+		}
+		return list;
+	}
+	
+	/**
+	 * 障害検知用通知情報マップを返します。
+	 * <p>
+	 * <ol>
+	 * <li>障害検知用の通知情報を取得します。</li>
+	 * <li>通知情報マップに、通知情報をセットします。</li>
+	 *  <dl>
+	 *   <dt>通知情報マップ</dt>
+	 *   <dd>キー：通知ID</dd>
+	 *   <dd>値　：通知情報</dd>
+	 *  </dl>
+	 * </li>
+	 * </ol>
+	 * 
+	 * @return 通知情報マップ
+	 * @throws FinderException
+	 * @throws NamingException
+	 */
+	public HashMap<String, NotifyInfo> getTroubleDetectionNotifyMap() throws FinderException, NamingException {
+
+		HashMap<String, NotifyInfo> map = new HashMap<String, NotifyInfo>();
+		try 
+		{
+			// 通知情報一覧を取得
+			Collection<NotifyInfoLocal> ct = NotifyInfoUtil.getLocalHome().findByUseType(HinemosModuleConstant.SYSYTEM_TROUBLE_DETECTION+"%");
+			
+			Iterator<NotifyInfoLocal> itr = ct.iterator();
+			NotifyInfo bean = null;
+			NotifyInfoLocal notify = null;
+
+			while(itr.hasNext()){
+				
+				notify = (NotifyInfoLocal)itr.next();
+				bean = getNotify(notify);
+				
+				map.put(notify.getNotifyId(), bean);
+			}
+			
+		} catch (FinderException e) {
+			AplLogger apllog = new AplLogger("NOTIFY", "notify");
+			apllog.put("SYS", "006");
+			m_log.debug("getNotifyMap():" + e.getMessage());
+			throw e;
+		} catch (NamingException e) {
+			AplLogger apllog = new AplLogger("NOTIFY", "notify");
+			apllog.put("SYS", "006");
+			m_log.debug("getTroubleDetectionNotifyMap():" + e.getMessage());
+			throw e;
+		}
+		return map;
+	}
+	
 	
 	/**
 	 * DBより取得した通知情報のObjectの2次元配列を返します。
