@@ -15,13 +15,12 @@
 
 package com.clustercontrol.ping.factory;
 
-import java.io.IOException;
-import java.io.InputStream;
-import java.io.StreamTokenizer;
-import java.io.StringReader;
+import java.net.InetAddress;
+import java.net.UnknownHostException;
 import java.util.ArrayList;
 import java.util.Date;
 import java.util.HashMap;
+import java.util.Hashtable;
 import java.util.Iterator;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
@@ -46,6 +45,7 @@ import com.clustercontrol.bean.PingRunCountConstant;
 import com.clustercontrol.bean.PingRunIntervalConstant;
 import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.monitor.run.bean.MonitorNumericValueInfo;
+import com.clustercontrol.monitor.run.factory.RunMonitor;
 import com.clustercontrol.monitor.run.factory.RunMonitorNumericValueType;
 import com.clustercontrol.ping.bean.PingResult;
 import com.clustercontrol.ping.ejb.entity.MonitorPingInfoLocal;
@@ -56,9 +56,7 @@ import com.clustercontrol.ping.util.ReachAddress;
 import com.clustercontrol.ping.util.ReachAddressFping;
 import com.clustercontrol.priority.util.PriorityJudgment;
 import com.clustercontrol.repository.bean.FacilityAttributeConstant;
-import com.clustercontrol.repository.ejb.session.RepositoryControllerBean;
 import com.clustercontrol.util.Messages;
-import com.sun.org.apache.xalan.internal.xsltc.runtime.Hashtable;
 
 /**
  * ping監視を実行するクラス<BR>
@@ -76,11 +74,12 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 	public static final String MESSAGE_ID_UNKNOWN = "004";
 	
 	public static boolean fpingEnable;
-
+	
 	
 	/** ping監視情報 */
 	protected static final ArrayList<String> m_attributeList = new ArrayList<String>();
 	static{
+		m_attributeList.add(FacilityAttributeConstant.IPPROTOCOLNUMBER);
 		m_attributeList.add(FacilityAttributeConstant.NODENAME);
 		m_attributeList.add(FacilityAttributeConstant.IPNETWORKNUMBER);
 		m_attributeList.add(FacilityAttributeConstant.IPNETWORKNUMBERV6);
@@ -131,6 +130,12 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 	//fping利用時のfpingエラー出力メッセージ
 	private ArrayList m_MsgErr= null;
 	
+	//fping利用時のfping出力メッセージ
+	private ArrayList m_MsgOrgV6= null;
+	
+	//fping利用時のfpingエラー出力メッセージ
+	private ArrayList m_MsgErrV6= null;
+	
 	
 	private Hashtable m_Target;
 	
@@ -143,7 +148,17 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 		super();
 		
 		PingProperties.getProperties();
-		fpingEnable=PingProperties.isM_fpingEnable();
+		fpingEnable=PingProperties.isFpingEnable();
+	}
+	
+	/**
+	 * マルチスレッドを実現するCallableTaskに渡すためのインスタンスを作成するメソッド
+	 * 
+	 * @see com.clustercontrol.monitor.run.factory.RunMonitor#runMonitorInfo()
+	 * @see com.clustercontrol.monitor.run.util.CallableTask
+	 */
+	public RunMonitor createMonitorInstance() throws NamingException, JMSException, CreateException{
+		return new RunMonitorPing();
 	}
 	
 	/**
@@ -215,14 +230,16 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 		
 		//まずは、データを作ります。
 		// hosts[] →　IPアドレスリスト(String の配列)
+		// hostsv6[] → IPv6アドレスリスト(Stringの配列)
 		// node    → IPアドレスとノード名のリスト
 		// target  → nodoのリスト
-
-		ArrayList hosts = new ArrayList();
-//		String[] hosts     = new String[facilityList.size()];
+		
+		ArrayList hosts     = new ArrayList();
+		ArrayList hostsv6   = new ArrayList();
 		m_Target = new Hashtable();
 		
 		String facilityId = null;
+		int version = 4;
 		String[] node;
 		for(int index=0; index<facilityList.size(); index++){
 			facilityId = (String)facilityList.get(index);
@@ -235,17 +252,44 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 					// ノードの属性取得
 					HashMap facilityAttrMap = m_repository.getNodeDetail(facilityId, m_attributeList);
 					
-					node[0] = (String)facilityAttrMap.get(FacilityAttributeConstant.IPNETWORKNUMBER);
-					node[1] = (String)facilityAttrMap.get(FacilityAttributeConstant.NODENAME);
-				
-					if (node[0] != null && !node[0].equals("")) {
-						//IPアドレスを配列に入れていく。
-						hosts.add(node[0]);
+					//m_log.error(facilityAttrMap.get(FacilityAttributeConstant.IPPROTOCOLNUMBER));
+					//プロトコルのバージョンが指定されていればversionを指定する。
+					
+					if((Integer)facilityAttrMap.get(FacilityAttributeConstant.IPPROTOCOLNUMBER) != null){
+						version = ((Integer)facilityAttrMap.get(FacilityAttributeConstant.IPPROTOCOLNUMBER)).intValue();
+					}else{
+						version = 4;
+					}
+					
+					if(version == 6){
 						
+						InetAddress[] ip = InetAddress.getAllByName((String)facilityAttrMap.get(FacilityAttributeConstant.IPNETWORKNUMBERV6));
+						
+						if(ip.length != 1){
+							//IPアドレスをInetAddressクラスでデコードしているのに1つじゃないときは
+							//UnnownHostExcption
+							throw new UnknownHostException();
+						}
+						
+						node[0] = ip[0].getHostAddress();
+						
+						if(node[0] != null && !node[0].equals("")){
+							
+							//IPアドレスをArryListに入れていく。
+							hostsv6.add(node[0]);
+						}
+					}else{
+						node[0] = (String)facilityAttrMap.get(FacilityAttributeConstant.IPNETWORKNUMBER);
+						if(node[0] != null && !node[0].equals("")){
+							//IPアドレスをArryListに入れていく。
+							hosts.add(node[0]);
+						}
+					}
+					if(node[0] != null && !node[0].equals("")){
+						node[1] = (String)facilityAttrMap.get(FacilityAttributeConstant.NODENAME);
 						//targetをつめていく。
 						m_Target.put(facilityId,node);
 					}
-					
 				}catch(FinderException e){
 					m_log.error("collectFping():" + e.getMessage());
 					
@@ -259,6 +303,9 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 					m_message = Messages.getString("message.ping.4");
 					m_messageOrg = e.getMessage();
 					return false;
+				} catch (UnknownHostException e) {
+					
+					e.printStackTrace();
 				}
 			}	
 		}
@@ -267,10 +314,26 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 			m_reachabilityFping = new ReachAddressFping(m_runCount, m_runInterval, m_pingTimeout);
 		}
 		
-		boolean result = m_reachabilityFping.isReachable(hosts);
-		m_MsgErr = m_reachabilityFping.getM_errMsg();
-		m_MsgOrg = m_reachabilityFping.getM_resultMsg();	
-		
+		boolean result=true;
+		boolean resultTmp=true;
+		//IPv4のホストが在ればfpingを利用して監視
+		if(hosts.size() !=0 ) { 
+			
+			result = m_reachabilityFping.isReachable(hosts , 4);
+			m_MsgErr = m_reachabilityFping.getM_errMsg();
+			m_MsgOrg = m_reachabilityFping.getM_resultMsg();	
+			
+		}
+		//IPv6のホストが在ればfping6を利用して監視
+		if(hostsv6.size() !=0 ) { 
+			
+			resultTmp = m_reachabilityFping.isReachable(hostsv6 , 6);
+			m_MsgErrV6 = m_reachabilityFping.getM_errMsg();
+			m_MsgOrgV6 = m_reachabilityFping.getM_resultMsg();	
+			
+			//結果は&であわせる
+			result = result & resultTmp;
+		}
 		return result;
 	}
 	
@@ -283,7 +346,7 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 	 * @param count      ping回数
 	 * @return (IPアドレス 応答率、平均応答時間)のハッシュテーブル
 	 */
-	private Hashtable wrapUpFping(ArrayList messages,int count){
+	private Hashtable wrapUpFping(ArrayList messages,  int count, int version){
 		
 		Hashtable ret = new Hashtable();
 		/**
@@ -298,7 +361,14 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 		float reachRatio;
 		
 		//IPアドレスの正規表現パターン
-		Pattern patternIp = Pattern.compile("^([0-9]{1,3}\\.[0-9]{1,3}\\.[0-9]{1,3}\\.[0-9]{1,3}.*)");
+		
+		Pattern patternIp;
+		if (version == 6){
+			patternIp = Pattern.compile("^([0-9].*)|^(\\:\\:.*)");
+		}else{
+			patternIp = Pattern.compile("^([0-9]{1,3}\\.[0-9]{1,3}\\.[0-9]{1,3}\\.[0-9]{1,3}.*)");
+		}
+		
 		//fpingの出力を分割するパターン
 		Pattern patternSp = Pattern.compile("(\\s:\\s|\\s)+");
 		Matcher matcher;
@@ -375,7 +445,7 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 				
 				msgOrg =buffer.toString();
 				msg= "Packets: Sent = " + count + ", Received = " + num + ", Lost = " + (count-num) + " (" + lost + "% loss)";
-
+				
 				PingResult res = new PingResult(strs[0],msg,msgOrg,lost,average, reachRatio);
 				
 				ret.put(strs[0],res); 
@@ -538,6 +608,7 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 	 * @see #notify(boolean, String, int, Date)
 	 */
 	@SuppressWarnings("unchecked")
+	@Override
 	public boolean runMonitorInfo()throws FinderException, RemoveException, JMSException, NamingException, CreateException {
 		
 		m_now = new Date();
@@ -564,23 +635,26 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 			setCheckInfo();
 			
 			// ファシリティIDの配下全ての一覧を取得
-			ArrayList facilityList = m_repository.getNodeFacilityIdList(m_facilityId, RepositoryControllerBean.ALL);
+			ArrayList facilityList = m_repository.getExecTargetFacilityIdList(m_facilityId);
+//			ArrayList facilityList = m_repository.getNodeFacilityIdList(m_facilityId, RepositoryControllerBean.ALL);
+//			
+//			//配下にノードがないということはノードの可能性があるので指定されたIDをセット
+//			if (facilityList.size() == 0) {
+//				if(m_repository.isNode(m_facilityId)){
+//					m_isNode = true;
+//					facilityList.add(m_facilityId);
+//				}
+//				else{
+//					return true;
+//				}
+//			}
+			if (facilityList.size() == 0) return true;
 			
-			//配下にノードがないということはノードの可能性があるので指定されたIDをセット
-			if (facilityList.size() == 0) {
-				if(m_repository.isNode(m_facilityId)){
-					m_isNode = true;
-					facilityList.add(m_facilityId);
-				}
-				else{
-					return true;
-				}
-			}
 			
 			// ファシリティ毎に監視情報を収集
 			ArrayList<Integer> priorityList = new ArrayList<Integer>();
 			
-
+			
 			//fping利用フラグがfalseの時はver2.2までの方式でping監視を行う。
 			if(!fpingEnable){
 				
@@ -630,8 +704,21 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 				
 				
 				if(ret){
+					Hashtable fpingResultSet = new Hashtable();
+					Hashtable fpingResultSetV6 = new Hashtable();
 					//データの整形を行います。
-					Hashtable fpingResultSet = wrapUpFping(m_MsgErr,m_runCount);
+					if(m_MsgErr != null){
+						fpingResultSet = wrapUpFping(m_MsgErr, m_runCount,4);
+					}
+					if(m_MsgErrV6 != null){
+						fpingResultSetV6 = wrapUpFping(m_MsgErrV6, m_runCount,6);
+					}
+					
+					if( fpingResultSet.size() == 0){
+						fpingResultSet = fpingResultSetV6;
+					}else if(fpingResultSetV6 .size()!= 0){
+						fpingResultSet.putAll(fpingResultSetV6);
+					}
 					
 					//最初に呼び出されたIPアドレスのリスト
 					Iterator it = facilityList.iterator();
