@@ -15,6 +15,8 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.process.bean;
 
+import java.util.ArrayList;
+
 /**
  * プロセス監視に必要なOIDを定義するクラス<BR>
  *
@@ -23,9 +25,18 @@ package com.clustercontrol.process.bean;
  */
 public class SnmpSharedTableConstant {
 	
-    public static final String JNDI_NAME = "SnmpProc";
+    public final static String SHARED_TABLE_JNDI_NAME = "SharedTable";
+    public final static String POLLER_MANAGER_JNDI_NAME = "SnmpPollerManager";
     
     public static final String OID_RUN_NAME  = ".1.3.6.1.2.1.25.4.2.1.2";
     public static final String OID_RUN_PATH  = ".1.3.6.1.2.1.25.4.2.1.4";
     public static final String OID_RUN_PARAM = ".1.3.6.1.2.1.25.4.2.1.5";
+    
+    public static final ArrayList<String> PROCESS_OIDS = new ArrayList<String>();
+ 
+    static {
+    	PROCESS_OIDS.add(OID_RUN_NAME);
+    	PROCESS_OIDS.add(OID_RUN_PATH);
+    	PROCESS_OIDS.add(OID_RUN_PARAM);
+    }
 }
