@@ -17,8 +17,10 @@ package com.clustercontrol.process.factory;
 
 import java.text.DateFormat;
 import java.text.NumberFormat;
+import java.util.ArrayList;
 import java.util.Calendar;
 import java.util.Date;
+import java.util.HashMap;
 import java.util.Iterator;
 import java.util.Set;
 import java.util.regex.Matcher;
@@ -48,6 +50,9 @@ import com.clustercontrol.process.ejb.entity.MonitorProcessInfoPK;
 import com.clustercontrol.process.ejb.entity.MonitorProcessInfoUtil;
 import com.clustercontrol.process.util.ProcessProperties;
 import com.clustercontrol.process.util.SnmpProcConnectionManager;
+import com.clustercontrol.repository.bean.FacilityAttributeConstant;
+import com.clustercontrol.repository.ejb.session.RepositoryControllerLocal;
+import com.clustercontrol.repository.ejb.session.RepositoryControllerUtil;
 import com.clustercontrol.sharedtable.DataTable;
 import com.clustercontrol.sharedtable.DataTableNotFoundException;
 import com.clustercontrol.sharedtable.SharedTable;
@@ -57,7 +62,7 @@ import com.clustercontrol.util.Messages;
 /**
  * プロセス監視を実行するクラス<BR>
  *
- * @version 2.0.0
+ * @version 3.0.4
  * @since 2.0.0
  */
 public class RunMonitorProcess extends RunMonitorNumericValueType {
@@ -169,11 +174,13 @@ public class RunMonitorProcess extends RunMonitorNumericValueType {
 		} catch (NotInitializedException e) {
 			// 以下のエラーチェックで処理
 		}
+		
+		// テーブルが存在するか否かを示すフラグ 
+		boolean isGetDateTable = true;
 		// テーブルが存在しない場合は作成
 		if(table == null){
 			// マルチスレッド対応（同時に呼ばれる可能性があるためsynchronized化し、再度getDataTableを試みる）
 			synchronized (m_syncObj) {
-				boolean isGetDateTable = true;
 				try {
 					setSnmpSharedTable();
 					table = m_sst.getDataTable(m_monitorTypeId, facilityId, m_monitorId, 0);
@@ -186,7 +193,7 @@ public class RunMonitorProcess extends RunMonitorNumericValueType {
 				}
 				
 				if(!isGetDateTable){
-					m_log.warn("Create Table (" + facilityId + ", " + m_monitorId + ")");
+					m_log.debug("Create Table (" + facilityId + ", " + m_monitorId + ")");
 					m_sst.createDataTable(m_monitorTypeId, facilityId, 1);
 					try {
 						// 実行間隔
@@ -236,10 +243,18 @@ public class RunMonitorProcess extends RunMonitorNumericValueType {
 			 * これがNULLの時は"不明を返す"
 			 */
 			if (valueSetName == null || valueSetParam == null || valueSetCommand == null) {
-				m_log.warn("collect()  FacilityID : "
-								+ facilityId
-								+ ", "
-								+ "valueSetName(Set) or valueSetParam(Set) or valueSetPath(Set) is null , SNMP Polling failed");
+				// テーブルがなく生成した場合は、直後に値がないのは当然であるため、ログレベルを下げて出力 
+				if (isGetDateTable == false) {
+					m_log.debug("collect()  FacilityID : "
+									+ facilityId
+									+ ", "
+									+ "valueSetName(Set) or valueSetParam(Set) or valueSetPath(Set) is null , SNMP Polling failed");
+				} else {
+					m_log.warn("collect()  FacilityID : "
+									+ facilityId
+									+ ", "
+									+ "valueSetName(Set) or valueSetParam(Set) or valueSetPath(Set) is null , SNMP Polling failed");
+				}
 
 				// ポーリングを行い再度プロセス数のカウントを行う
 				if (retryCount < MAX_RETRY_COUNT) {
@@ -509,8 +524,40 @@ public class RunMonitorProcess extends RunMonitorNumericValueType {
 		if(poller == null){
 			poller = manager.createPoller(m_monitorTypeId, facilityId, true, m_monitorTypeId, facilityId);
 		}
-		// ポーリングを実行（タイムアウト：3000ミリ秒、リトライ1回）
-		return poller.polling(3000, 1, SnmpSharedTableConstant.PROCESS_OIDS);
+		
+		Integer timeout = 3000;
+		Integer retryCount = 1;
+		
+		// facilityIdを基に、タイムアウトとリトライ回数を取得する
+		try {
+			ArrayList<String> attributes = new ArrayList<String>();
+			attributes.add(FacilityAttributeConstant.SNMPTIMEOUT);
+			attributes.add(FacilityAttributeConstant.SNMPRETRIES);
+			
+			RepositoryControllerLocal repositoryLocal = RepositoryControllerUtil.getLocalHome().create();
+			HashMap<String, Object> nodeInfo = repositoryLocal.getNodeDetail(facilityId, attributes);
+			
+			Object snmpTimeout = nodeInfo.get(FacilityAttributeConstant.SNMPTIMEOUT);
+			Object snmpRetryCount = nodeInfo.get(FacilityAttributeConstant.SNMPRETRIES);
+			
+			if(snmpTimeout != null) {
+				timeout = (Integer)snmpTimeout;
+			}
+			
+			if(snmpRetryCount != null) {
+				retryCount = (Integer)snmpRetryCount;
+			}
+			
+		} catch (CreateException e) {
+			m_log.error(e.getMessage(), e);
+		} catch (FinderException e) {
+			m_log.error(e.getMessage(), e);
+		}
+		
+		m_log.debug("retryPolling() : facilityId : " + facilityId + ", timeout : " + timeout + ", retryCount : " + retryCount);
+		
+		// ポーリングを実行
+		return poller.polling(timeout, retryCount, SnmpSharedTableConstant.PROCESS_OIDS);
 	}
 	
 	
