@@ -66,7 +66,7 @@ import com.clustercontrol.util.PropertyUtil;
 /**
  * ノードの作成・変更ダイアログクラス<BR>
  * 
- * @version 2.2.0
+ * @version 3.0.1
  * @since 1.0.0
  */
 public class NodeCreateDialog extends CommonDialog {
@@ -652,7 +652,7 @@ public class NodeCreateDialog extends CommonDialog {
 			//ルール１：
 			//デバイスINDEXとデバイスTYPEが入力してある、かつ、デバイス名が未入力の場合は、エラーを表示
 			//ルール２：
-			//デバイスTYPEに「disk」「nic」以外の文字が入力してある場合は、エラをー表示
+			//(ver3.0.1より廃止)デバイスTYPEに「disk」「nic」以外の文字が入力してある場合は、エラをー表示
 			//ルール３：
 			//デバイス名に重複がある場合は、エラーを表示
 			values = PropertyUtil.getPropertyValue(getInputData(), NodeProperty.DEVICE_INDEX);
@@ -689,7 +689,9 @@ public class NodeCreateDialog extends CommonDialog {
 			            return result;
 					}
 					
+					//nic、disk以外の文字列の入力も許可するため、以下のチェックをコメントアウトした ver3.0.1 uchiyama
 					//デバイスTYPEに「disk」「nic」以外が入力されている
+					/*
 					if(!deviceType.equals(DeviceTypeConstant.DEVICE_DISK) && !deviceType.equals(DeviceTypeConstant.DEVICE_NIC)) {
 						String[] args = { deviceName, DeviceTypeConstant.DEVICE_DISK, DeviceTypeConstant.DEVICE_NIC };
 						result = new ValidateResult();
@@ -698,6 +700,26 @@ public class NodeCreateDialog extends CommonDialog {
 			            result.setValid(false);
 			            return result;
 					}
+					*/
+					
+					// デバイスタイプにて入力不可文字が使用されていないかをチェック
+					String[] args = {deviceName};
+					if(deviceType.matches(".*[\\\\/;,<>+\"]+.*")) {
+			            result = new ValidateResult();
+			            result.setID(Messages.getString("message.hinemos.1"));
+			            result.setMessage(Messages.getString("message.repository.29", args));
+			            result.setValid(false);
+			            return result;
+					}
+					else if(deviceType.matches("#.*")) {
+			            result = new ValidateResult();
+			            result.setID(Messages.getString("message.hinemos.1"));
+			            result.setMessage(Messages.getString("message.repository.30", args));
+			            result.setValid(false);
+			            return result;
+					}
+					
+					
 					
 					checkDn.add(deviceType+"_"+deviceIndex);
 					checkName.add(deviceName);
