@@ -35,6 +35,8 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.accesscontrol.util.LdapConnectionManager;
+import com.clustercontrol.accesscontrol.util.TimeKeeper;
+import com.clustercontrol.accesscontrol.util.TimeKeeperService;
 import com.clustercontrol.bean.FacilityConstant;
 import com.clustercontrol.bean.SnmpVersionConstant;
 import com.clustercontrol.repository.bean.FacilityAttributeConstant;
@@ -74,13 +76,16 @@ public class FacilityDAOImpl implements FacilityDAO {
 		
 		int retryCount=0;
 		while(MAX_RETRY > retryCount){
-				
+			TimeKeeper timer = null;
 			try {
 				clearBean(ejb);
 				
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
 				//dnをキーとしてLDAPアクセスし、属性を取得
 //				javax.naming.directory.Attributes attrs = ctx.getAttributes(pk.getDn());
 				javax.naming.directory.Attributes attrs = ctx.getAttributes(createDnString(pk.getFacilityId()));
@@ -341,8 +346,11 @@ public class FacilityDAOImpl implements FacilityDAO {
 						ctx.close();
 					}
 				} catch (NamingException e) {
-					m_log.error("load() context close failed : " + e.getMessage());
+					m_log.error("load() context close failed : " + e.getMessage(), e);
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 			return;
 		}
@@ -356,11 +364,14 @@ public class FacilityDAOImpl implements FacilityDAO {
 		
 		int retryCount=0;
 		while(MAX_RETRY > retryCount){
-				
+			TimeKeeper timer = null;
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
 				//dnをキーとしてLDAPアクセスし、属性を取得
 				javax.naming.directory.Attributes attrs = ctx.getAttributes(ejb.getDn());
 				
@@ -900,8 +911,11 @@ public class FacilityDAOImpl implements FacilityDAO {
 						ctx.close();
 					}
 				} catch (NamingException e) {
-					m_log.error("store() context close failed : " + e.getMessage());
+					m_log.error("store() context close failed : " + e.getMessage(), e);
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 			return ;
 		}
@@ -915,10 +929,13 @@ public class FacilityDAOImpl implements FacilityDAO {
 		
 		int retryCount=0;
 		while(MAX_RETRY > retryCount){
-			
+			TimeKeeper timer = null;
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
+
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
 	
 				//dnをキーとしてLDAPアクセスし、エントリを削除
 //				ctx.destroySubcontext(pk.getDn());
@@ -968,8 +985,11 @@ public class FacilityDAOImpl implements FacilityDAO {
 						ctx.close();
 					}
 				} catch (NamingException e) {
-					m_log.error("remove() context close failed : " + e.getMessage());
+					m_log.error("remove() context close failed : " + e.getMessage(), e);
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 			return;
 		}
@@ -986,11 +1006,14 @@ public class FacilityDAOImpl implements FacilityDAO {
 		
 		int retryCount=0;
 		while(MAX_RETRY > retryCount){
-				
+			TimeKeeper timer = null;
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
 				// Attributes for new entry
 				javax.naming.directory.Attributes attrs =
 					new javax.naming.directory.BasicAttributes();
@@ -1088,8 +1111,11 @@ public class FacilityDAOImpl implements FacilityDAO {
 						ctx.close();
 					}
 				} catch (NamingException e) {
-					m_log.error("create() context close failed : " + e.getMessage());
+					m_log.error("create() context close failed : " + e.getMessage(), e);
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 	
 			return pk;
@@ -1128,10 +1154,14 @@ public class FacilityDAOImpl implements FacilityDAO {
 		int retryCount=0;
 		
 		while(MAX_RETRY > retryCount){
+			TimeKeeper timer = null;
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
 				results = ctx.search(BASE_DN, search.toString(), constraints);
 				
 				if (results == null) {
@@ -1195,8 +1225,11 @@ public class FacilityDAOImpl implements FacilityDAO {
 					if(ctx != null)
 						ctx.close();
 				} catch (NamingException e) {
-					m_log.error("findAll() context close failed : " + e.getMessage());
+					m_log.error("findAll() context close failed : " + e.getMessage(), e);
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 			
 			return ret;
@@ -1237,11 +1270,14 @@ public class FacilityDAOImpl implements FacilityDAO {
 		int retryCount=0;
 		
 		while(MAX_RETRY > retryCount){
-			
+			TimeKeeper timer = null;
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
 				results = ctx.search(BASE_DN, search.toString(), constraints);
 				
 				if (results == null ) {
@@ -1305,8 +1341,11 @@ public class FacilityDAOImpl implements FacilityDAO {
 					if(ctx != null)
 						ctx.close();
 				} catch (NamingException e) {
-					m_log.error("findAllNode() context close failed : " + e.getMessage());
+					m_log.error("findAllNode() context close failed : " + e.getMessage(), e);
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 			
 			return ret;
@@ -1321,6 +1360,7 @@ public class FacilityDAOImpl implements FacilityDAO {
 		javax.naming.directory.DirContext ctx = null;
 		int retryCount=0;
 		while(MAX_RETRY > retryCount){
+			TimeKeeper timer = null;
 			try {
 //				m_log.debug("findByPrimaryKey() : dn = " + pk.getDn());
 				m_log.debug("findByPrimaryKey() : facilityId = " + pk.getFacilityId());
@@ -1328,6 +1368,9 @@ public class FacilityDAOImpl implements FacilityDAO {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
 				//dnをキーとしてLDAPアクセスし、属性を取得
 //				javax.naming.directory.Attributes attrs = ctx.getAttributes(pk.getDn());
 				javax.naming.directory.Attributes attrs = ctx.getAttributes(createDnString(pk.getFacilityId()));
@@ -1377,8 +1420,11 @@ public class FacilityDAOImpl implements FacilityDAO {
 						ctx.close();
 					}
 				} catch (NamingException e) {
-					m_log.error("findByPrimaryKey() context close failed : " + e.getMessage());
+					m_log.error("findByPrimaryKey() context close failed : " + e.getMessage(), e);
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 			return pk;
 		}
@@ -1389,11 +1435,11 @@ public class FacilityDAOImpl implements FacilityDAO {
 	 * @see com.clustercontrol.repository.dao.FacilityDAO#findByFacilityId(java.lang.String)
 	 */
 	public FacilityPK findByFacilityId(String facilityId) throws FinderException {
-		
-		m_log.debug("start");
-		
+		m_log.debug("findByFacilityId() start : FacilityId = " + facilityId);
+			
 		FacilityPK pk = new FacilityPK(facilityId);
-		m_log.debug("end");
+		
+		m_log.debug("findByFacilityId() end  : FacilityId = " + facilityId);
 		return pk;
 		
 		
@@ -1620,10 +1666,14 @@ public class FacilityDAOImpl implements FacilityDAO {
 		int retryCount=0;
 		
 		while(MAX_RETRY > retryCount){
+			TimeKeeper timer = null;
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
 				results = ctx.search(BASE_DN, search.toString(), constraints);
 				
 				if (results == null ) {
@@ -1697,8 +1747,11 @@ public class FacilityDAOImpl implements FacilityDAO {
 					if(ctx != null)
 						ctx.close();
 				} catch (NamingException e) {
-					m_log.error("findNode() context close failed : " + e.getMessage());
+					m_log.error("findNode() context close failed : " + e.getMessage(), e);
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 			
 			return ret;
@@ -1747,10 +1800,14 @@ public class FacilityDAOImpl implements FacilityDAO {
 		int retryCount=0;
 		
 		while(MAX_RETRY > retryCount){
+			TimeKeeper timer = null;
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
 				results = ctx.search(BASE_DN, search.toString(), constraints);
 				
 				if (results == null ) {
@@ -1814,8 +1871,11 @@ public class FacilityDAOImpl implements FacilityDAO {
 					if(ctx != null)
 						ctx.close();
 				} catch (NamingException e) {
-					m_log.error("findByIpAddress() context close failed : " + e.getMessage());
+					m_log.error("findByIpAddress() context close failed : " + e.getMessage(), e);
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 	
 			return ret;
@@ -1863,12 +1923,14 @@ public class FacilityDAOImpl implements FacilityDAO {
 		
 		int retryCount=0;
 		while(MAX_RETRY > retryCount){
-			
-				
+			TimeKeeper timer = null;
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
 				results = ctx.search(BASE_DN, search.toString(), constraints);
 				
 				if (results == null ) {
@@ -1929,8 +1991,11 @@ public class FacilityDAOImpl implements FacilityDAO {
 					if(ctx != null)
 						ctx.close();
 				} catch (NamingException e) {
-					m_log.error("findByNodeName() context close failed : " + e.getMessage());
+					m_log.error("findByNodeName() context close failed : " + e.getMessage(), e);
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 			return ret;
 	    }
