@@ -29,6 +29,8 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.accesscontrol.util.LdapConnectionManager;
+import com.clustercontrol.accesscontrol.util.TimeKeeper;
+import com.clustercontrol.accesscontrol.util.TimeKeeperService;
 import com.clustercontrol.repository.bean.DeviceInfoAttributeConstant;
 import com.clustercontrol.repository.bean.FileSystemInfoAttributeConstant;
 import com.clustercontrol.repository.ejb.entity.FileSystemInfoBean;
@@ -65,13 +67,16 @@ public class FileSystemInfoDAOImpl implements FileSystemInfoDAO {
 		
 		int retryCount=0;
 		while(MAX_RETRY > retryCount){
-			
+			TimeKeeper timer = null;
 			try {
 				clearBean(ejb);
 				
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
 				//属性を取得
 				javax.naming.directory.Attributes attrs = ctx.getAttributes(pk.getDn());
 	
@@ -147,6 +152,9 @@ public class FileSystemInfoDAOImpl implements FileSystemInfoDAO {
 				} catch (NamingException e) {
 					m_log.error("load() context close failed : " + e.getMessage());
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 			return;
 		}
@@ -159,11 +167,14 @@ public class FileSystemInfoDAOImpl implements FileSystemInfoDAO {
 		javax.naming.directory.DirContext ctx = null;
 		int retryCount=0;
 		while(MAX_RETRY > retryCount){
-				
+			TimeKeeper timer = null;
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
 				//属性を取得
 				javax.naming.directory.Attributes attrs = ctx.getAttributes(ejb.getDn());
 				
@@ -280,6 +291,9 @@ public class FileSystemInfoDAOImpl implements FileSystemInfoDAO {
 				} catch (NamingException e) {
 					m_log.error("store() context close failed : " + e.getMessage());
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 			return;
 		}
@@ -292,10 +306,14 @@ public class FileSystemInfoDAOImpl implements FileSystemInfoDAO {
 		javax.naming.directory.DirContext ctx = null;
 		int retryCount=0;
 		while(MAX_RETRY > retryCount){
+			TimeKeeper timer = null;
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
 				//エントリを削除
 				ctx.destroySubcontext(pk.getDn());
 				return;
@@ -341,6 +359,9 @@ public class FileSystemInfoDAOImpl implements FileSystemInfoDAO {
 				} catch (NamingException e) {
 					m_log.error("remove() context close failed : " + e.getMessage());
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 		}
 	}
@@ -353,6 +374,7 @@ public class FileSystemInfoDAOImpl implements FileSystemInfoDAO {
 		javax.naming.directory.DirContext ctx = null;
 		int retryCount=0;	
 		while(MAX_RETRY > retryCount){
+			TimeKeeper timer = null;
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
@@ -378,7 +400,28 @@ public class FileSystemInfoDAOImpl implements FileSystemInfoDAO {
 				
 				//dn設定
 				ejb.setDn(dn.toString());
-	
+				
+				// 各種属性値をセットする
+				
+				if (ejb.getSnmpOID() != null) {
+					attrs.put(FileSystemInfoAttributeConstant.FILESYSTEMSNMPOID, ejb.getSnmpOID());
+				}
+				
+				if (ejb.getFileSystemMountPoint() != null) {
+					attrs.put(FileSystemInfoAttributeConstant.FILESYSTEMMOUNTPOINT, ejb.getFileSystemMountPoint());
+				}
+				
+				if (ejb.getFileSystemType() != null) {
+					attrs.put(FileSystemInfoAttributeConstant.FILESYSTEMTYPE, ejb.getFileSystemType());
+				}
+				
+				if (ejb.getDescription() != null) {
+					attrs.put(FileSystemInfoAttributeConstant.DESCRIPTION, ejb.getDescription());
+				}
+				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
 				//エントリ作成
 				ctx.createSubcontext(ejb.getDn(), attrs);
 	
@@ -441,6 +484,9 @@ public class FileSystemInfoDAOImpl implements FileSystemInfoDAO {
 				} catch (NamingException e) {
 					m_log.error("create() context close failed : " + e.getMessage());
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 		}
 		return pk;
@@ -475,11 +521,14 @@ public class FileSystemInfoDAOImpl implements FileSystemInfoDAO {
 		
 		int retryCount=0;
 		while(MAX_RETRY > retryCount){
-			
+			TimeKeeper timer = null;
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
 				results = ctx.search(BASE_DN, search.toString(), constraints);
 				
 				if (results == null ) {
@@ -540,6 +589,9 @@ public class FileSystemInfoDAOImpl implements FileSystemInfoDAO {
 				} catch (NamingException e) {
 					m_log.error("findAll() context close failed : " + e.getMessage());
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 		}
 		return ret;
@@ -554,13 +606,16 @@ public class FileSystemInfoDAOImpl implements FileSystemInfoDAO {
 		int retryCount=0;
 		
 		while(MAX_RETRY > retryCount){
-			
+			TimeKeeper timer = null;
 			try {
 				m_log.debug("findByPrimaryKey() : dn = " + pk.getDn());
 				
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
 				//属性を取得
 				javax.naming.directory.Attributes attrs = ctx.getAttributes(pk.getDn());
 				
@@ -612,6 +667,9 @@ public class FileSystemInfoDAOImpl implements FileSystemInfoDAO {
 				} catch (NamingException e) {
 					m_log.error("findByPrimaryKey() context close failed : " + e.getMessage());
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 			return pk;
 		}
@@ -656,11 +714,14 @@ public class FileSystemInfoDAOImpl implements FileSystemInfoDAO {
 		int retryCount=0;
 		
 		while(MAX_RETRY > retryCount){
-			
+			TimeKeeper timer = null;
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
 				results = ctx.search(baseDn.toString(), search.toString(), constraints);
 				
 				if (results == null ) {
@@ -721,6 +782,9 @@ public class FileSystemInfoDAOImpl implements FileSystemInfoDAO {
 				} catch (NamingException e) {
 					m_log.error("findByFacilityId() context close failed : " + e.getMessage());
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 			return ret;
 		}
@@ -766,11 +830,14 @@ public class FileSystemInfoDAOImpl implements FileSystemInfoDAO {
 		
 		int retryCount=0;
 		while(MAX_RETRY > retryCount){
-			
+			TimeKeeper timer = null;
 			try {
 				// LDAP用のコンテキストの作成
 				ctx = LdapConnectionManager.getConnectionManager().getDirContext();
 				
+				// LDAPへのアクセスが無応答になった場合に処理を中断するためのタイマースレッドを起動する。
+				timer = TimeKeeperService.start();
+				
 				results = ctx.search(baseDn.toString(), search.toString(), constraints);
 				
 				//検索結果を取得
@@ -828,6 +895,9 @@ public class FileSystemInfoDAOImpl implements FileSystemInfoDAO {
 				} catch (NamingException e) {
 					m_log.error("findByFacilityIdAndName() context close failed : " + e.getMessage());
 				}
+				
+				// タイマースレッドを停止
+				TimeKeeperService.stop(timer);
 			}
 			return pk;
 		}
