@@ -1024,6 +1024,8 @@ public abstract class RepositoryControllerBean implements javax.ejb.SessionBean
 	 */
 	public void addNode(Property property) throws NamingException, CreateException, FinderException {
  		Principal pri = m_context.getCallerPrincipal();
+ 		
+ 		this.checkFacilityInfo(property);
 			
 		ModifyFacility modify = new ModifyFacility();
 		modify.addNode(property, pri.getName()); //pri.getName()はメソッドの実行ユーザ
@@ -1064,6 +1066,8 @@ public abstract class RepositoryControllerBean implements javax.ejb.SessionBean
 		try {
 			Principal pri = m_context.getCallerPrincipal();
 			
+			this.checkFacilityInfo(property);
+			
 			ModifyFacility modify = new ModifyFacility();
 			modify.modifyNode(property, pri.getName());
 			
@@ -1104,6 +1108,8 @@ public abstract class RepositoryControllerBean implements javax.ejb.SessionBean
 		try {
 			Principal pri = m_context.getCallerPrincipal();
 			
+	 		this.checkFacilityInfo(property);
+			
 			ModifyFacility modify = new ModifyFacility();
 			modify.modifyAllNode(property, parentFacilityId, pri.getName());
 		} catch (NamingException e) {
@@ -1523,4 +1529,141 @@ public abstract class RepositoryControllerBean implements javax.ejb.SessionBean
             
     }
 	
-}
+
+	/**
+	 * 
+	 * ノード登録・変更時に入力情報が正しいかチェックするためのメソッド。
+	 * 不正な場合、EJBExceptionをスローする。
+	 * 
+	 * チェック内容は、入力必須項目が入力されているかどうか。
+	 * 文字数のチェックはしない。
+	 * 
+	 * @param property
+	 * @throws EJBException
+	 */
+	private void checkFacilityInfo(Property property) throws EJBException {
+		
+		ArrayList values = null;
+		
+		//ファシリティID取得
+		values = PropertyUtil.getPropertyValue(property, NodeProperty.FACILITY_ID);
+		String facilityId = checkString(values.get(0));
+		if (facilityId == null) {
+			throw new EJBException("facilityId is null");
+		}
+		
+		//ファシリティ名取得
+		values = PropertyUtil.getPropertyValue(property, NodeProperty.FACILITY_NAME);
+		String facilityName = checkString(values.get(0));
+		if (facilityName == null) {
+			throw new EJBException("facilityId=" + facilityId + " : facilityName is null");
+		}
+		
+		//プラットフォームを取得
+		values = PropertyUtil.getPropertyValue(property, NodeProperty.PLATFORM_FAMILY_NAME);
+		String platform = checkString(values.get(0));
+		if (platform == null) {
+			throw new EJBException("facilityId=" + facilityId + " : platform is null");
+		}
+		
+		//IPアドレスを取得
+		values = PropertyUtil.getPropertyValue(property, NodeProperty.IP_ADDRESS_V4);
+		String ip4Address = checkString(values.get(0));
+		if (ip4Address == null) {
+			throw new EJBException("facilityId=" + facilityId + " : ip4Address is null");
+		}
+		
+		//ノード名を取得
+		values = PropertyUtil.getPropertyValue(property, NodeProperty.NODE_NAME);
+		String nodeName = checkString(values.get(0));
+		if (nodeName == null) {
+			throw new EJBException("facilityId=" + facilityId + " : nodeName is null");
+		}
+		
+		
+		// デバイス情報のバリデーションチェック
+		ArrayList deviceList = PropertyUtil.getProperty(property, NodeProperty.DEVICE);
+		for(int i = 0; i < deviceList.size(); i++){
+		    //デバイスINDEXを取得
+			Property deviceProperty = (Property)deviceList.get(i);
+			
+			//デバイス名を取得
+			String deviceName = checkString(PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_NAME).get(0));
+			//デバイスインデックスを取得
+			Integer deviceIndex = checkInteger(PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_INDEX).get(0));
+			//デバイスタイプを取得
+			String deviceType = checkString(PropertyUtil.getPropertyValue(deviceProperty, NodeProperty.DEVICE_TYPE).get(0));
+			if ((deviceName == null || deviceName.equals("")) && deviceIndex == null && 
+				(deviceType == null || deviceType.equals(""))) {
+				continue;
+			}
+			if (deviceName == null) {
+				throw new EJBException("facilityId=" + facilityId + " : deviceName is null");
+			}
+			if (deviceIndex == null) {
+				throw new EJBException("facilityId=" + facilityId + ", deviceName=" + deviceName + " : deviceIndex is null");
+			}
+			if (deviceType == null) {
+				throw new EJBException("facilityId=" + facilityId + ", deviceName=" + deviceName + " : deviceType is null");
+			}
+			
+		}
+		
+		// ファイルシステム情報のバリデーションチェック			
+		ArrayList filesystemList = PropertyUtil.getProperty(property, NodeProperty.FILE_SYSTEM);
+		for(int i = 0; i < filesystemList.size(); i++){
+			
+			Property filesystemProperty = (Property)filesystemList.get(i);
+			
+			//ファイルシステムマウントポイントを取得
+			String mountPoint = checkString(PropertyUtil.getPropertyValue(filesystemProperty, NodeProperty.FILE_SYSTEM_MOUNT_POINT).get(0));
+			//ファイルシステムINDEXを取得
+			Integer filesystemIndex = checkInteger(PropertyUtil.getPropertyValue(filesystemProperty, NodeProperty.FILE_SYSTEM_INDEX).get(0));
+			if ((mountPoint == null || mountPoint.equals("")) && filesystemIndex == null) {
+				continue;
+			}
+			if (mountPoint == null) {
+				throw new EJBException("facilityId=" + facilityId + " : fileSystemMountPoint is null");
+			}
+			if (filesystemIndex == null) {
+				throw new EJBException("facilityId=" + facilityId + ", fileSystemMountPoint=" + mountPoint + " : fileSystemIndex is null");
+			}
+			
+		}
+	}
+	/**
+	 * Integerのインスタンスかチェックし、違っていればnullを返す
+	 * 
+	 * @param value
+	 * @return
+	 */
+    private Integer checkInteger(Object value){
+		if(value instanceof Integer){
+			return (Integer)value;
+		}
+		else{
+			return null;
+		}
+	}
+	
+	/**
+	 * Stringのインスタンスかチェックし、違っていればnullを返す
+	 * 
+	 * @param value
+	 * @return
+	 */
+	private String checkString(Object value){
+		if(value instanceof String){
+			if(((String)value).compareTo("") == 0){
+				return null;
+			}
+			else{
+				return (String)value;
+			}
+		}
+		else{
+			return null;
+		}
+	}
+	
+}
\ No newline at end of file
