@@ -15,7 +15,11 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.syslogng.dialog;
 
-import java.util.Date;
+import java.sql.Timestamp;
+import java.util.ArrayList;
+import java.util.Collection;
+import java.util.Iterator;
+import java.util.concurrent.CopyOnWriteArrayList;
 import java.util.regex.Pattern;
 import java.util.regex.PatternSyntaxException;
 
@@ -41,16 +45,16 @@ import com.clustercontrol.bean.FacilityConstant;
 import com.clustercontrol.bean.FacilityInfo;
 import com.clustercontrol.bean.FacilityPath;
 import com.clustercontrol.bean.FacilityTreeItem;
+import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.bean.ProcessConstant;
 import com.clustercontrol.bean.ValidConstant;
-import com.clustercontrol.bean.YesNoConstant;
 import com.clustercontrol.calendar.composite.CalendarIdListComposite;
 import com.clustercontrol.composite.StringVerifyListener;
 import com.clustercontrol.dialog.CommonDialog;
 import com.clustercontrol.dialog.ScopeTreeDialog;
 import com.clustercontrol.dialog.ValidateResult;
-import com.clustercontrol.jobmanagement.common.composite.JobIdSelectionListener;
+import com.clustercontrol.notify.bean.NotifyRelationInfo;
 import com.clustercontrol.notify.composite.NotifyInfoComposite;
 import com.clustercontrol.syslogng.action.LogManager;
 import com.clustercontrol.syslogng.bean.LogFilterInfo;
@@ -59,7 +63,7 @@ import com.clustercontrol.util.Messages;
 /**
  * syslog-ng[フィルタの作成・変更]ダイアログクラス<BR>
  * 
- * @version 2.2.0
+ * @version 3.0.0
  * @since 1.0.0
  */
 public class LogCreateDialog extends CommonDialog {
@@ -123,30 +127,7 @@ public class LogCreateDialog extends CommonDialog {
     /** メッセージ テキストボックス。 */
     private Text textLogMessage = null;
     
-    /**
-     * ジョブ実行 チェックボックス。
-     * @see com.clustercontrol.bean.YesNoConstant
-     */
-    private Button m_checkJobRun = null;
     
-    /** ジョブ実行のジョブID テキストボックス。 */
-	private Text m_textJobId = null;
-	
-	/** ジョブ実行の参照 ボタン。 */
-	private Button m_buttonRefer = null;
-	
-	/**
-	 * ジョブ実行の通知抑制と連動 チェックボックス。
-	 * @see com.clustercontrol.bean.YesNoConstant
-	 */ 
-	private Button m_checkInhibitionFlg = null;
-	
-	/**
-	 * ジョブ実行の呼出失敗時重要度 コンボボックス。
-	 * @see com.clustercontrol.bean.PriorityConstant
-	 */ 
-	private Combo m_comboFailurePriority = null;
-
     /**
      * この設定を有効にする チェックボックス。
      * @see com.clustercontrol.bean.ValidConstant
@@ -154,7 +135,7 @@ public class LogCreateDialog extends CommonDialog {
     private Button confirmValid = null;
     
     /** 作成日時。 */
-    private Date regDate = null;
+    private Timestamp regDate = null;
 
     /** 変更フラグ */
     private boolean modify = false;
@@ -506,150 +487,6 @@ public class LogCreateDialog extends CommonDialog {
         this.textLogMessage.addVerifyListener(
         		new StringVerifyListener(DataRangeConstant.VARCHAR_256));
         
-        // ジョブ実行
-        this.m_checkJobRun = new Button(group1, SWT.CHECK);
-        gridData = new GridData();
-        gridData.horizontalSpan = 15;
-        gridData.horizontalAlignment = GridData.FILL;
-        gridData.grabExcessHorizontalSpace = true;
-        m_checkJobRun.setLayoutData(gridData);
-        m_checkJobRun.setText(Messages.getString("run") + " : ");
-        m_checkJobRun.addSelectionListener(new SelectionAdapter() {
-            public void widgetSelected(SelectionEvent e) {
-            	m_textJobId.setEnabled(m_checkJobRun.getSelection());
-            	m_buttonRefer.setEnabled(m_checkJobRun.getSelection());
-            	m_checkInhibitionFlg.setEnabled(m_checkJobRun.getSelection());
-            	m_comboFailurePriority.setEnabled(m_checkJobRun.getSelection());
-            }
-        });
-		
-		// ジョブ実行グループ
-        Group groupRunJob = new Group(group1, SWT.NONE);
-        layout = new GridLayout(1, true);
-        layout.marginWidth = 5;
-        layout.marginHeight = 5;
-        layout.numColumns = 15;
-        groupRunJob.setLayout(layout);
-        gridData = new GridData();
-        gridData.horizontalSpan = 15;
-        gridData.horizontalAlignment = GridData.FILL;
-        gridData.grabExcessHorizontalSpace = true;
-        groupRunJob.setLayoutData(gridData);
-        
-        // ジョブID
-		label = new Label(groupRunJob, SWT.NONE);
-		gridData = new GridData();
-		gridData.horizontalSpan = 6;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		label.setLayoutData(gridData);
-		label.setText(Messages.getString("job.id"));
-		
-		// 空白
-        label = new Label(groupRunJob, SWT.NONE);
-        gridData = new GridData();
-        gridData.horizontalSpan = 1;
-        gridData.horizontalAlignment = GridData.FILL;
-        gridData.grabExcessHorizontalSpace = true;
-        label.setLayoutData(gridData);
-		
-		// 通知抑制と連動
-		label = new Label(groupRunJob, SWT.NONE);
-		gridData = new GridData();
-		gridData.horizontalSpan = 3;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		label.setLayoutData(gridData);
-		label.setText(Messages.getString("couple.with.notify.inhibition"));
-		
-		// 空白
-        label = new Label(groupRunJob, SWT.NONE);
-        gridData = new GridData();
-        gridData.horizontalSpan = 1;
-        gridData.horizontalAlignment = GridData.FILL;
-        gridData.grabExcessHorizontalSpace = true;
-        label.setLayoutData(gridData);
-		
-		// 呼出失敗時
-		label = new Label(groupRunJob, SWT.NONE);
-		gridData = new GridData();
-		gridData.horizontalSpan = 3;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		label.setLayoutData(gridData);
-		label.setText(Messages.getString("failure.call.value"));
-		
-		// 空白
-        label = new Label(groupRunJob, SWT.NONE);
-        gridData = new GridData();
-        gridData.horizontalSpan = 1;
-        gridData.horizontalAlignment = GridData.FILL;
-        gridData.grabExcessHorizontalSpace = true;
-        label.setLayoutData(gridData);
-		
-		/*
-         * 実行ジョブ
-         */
-        this.m_textJobId = new Text(groupRunJob, SWT.BORDER | SWT.LEFT | SWT.READ_ONLY);
-		gridData = new GridData();
-		gridData.horizontalSpan = 4;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		this.m_textJobId.setLayoutData(gridData);
-		
-		this.m_buttonRefer = new Button(groupRunJob, SWT.NONE);
-		gridData = new GridData();
-		gridData.horizontalSpan = 2;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		this.m_buttonRefer.setLayoutData(gridData);
-		this.m_buttonRefer.setText(Messages.getString("refer"));
-		this.m_buttonRefer.addSelectionListener(new JobIdSelectionListener(m_textJobId));
-		
-		// 空白
-        label = new Label(groupRunJob, SWT.NONE);
-        gridData = new GridData();
-        gridData.horizontalSpan = 1;
-        gridData.horizontalAlignment = GridData.FILL;
-        gridData.grabExcessHorizontalSpace = true;
-        label.setLayoutData(gridData);
-		
-        // 通知抑制と連動
-        this.m_checkInhibitionFlg = new Button(groupRunJob, SWT.CHECK);
-		gridData = new GridData();
-		gridData.horizontalSpan = 3;
-		gridData.horizontalAlignment = GridData.CENTER;
-		gridData.grabExcessHorizontalSpace = true;
-		this.m_checkInhibitionFlg.setLayoutData(gridData);
-		
-		// 空白
-        label = new Label(groupRunJob, SWT.NONE);
-        gridData = new GridData();
-        gridData.horizontalSpan = 1;
-        gridData.horizontalAlignment = GridData.FILL;
-        gridData.grabExcessHorizontalSpace = true;
-        label.setLayoutData(gridData);
-        
-        // 呼出失敗時
-        this.m_comboFailurePriority = new Combo(groupRunJob, SWT.DROP_DOWN | SWT.READ_ONLY);
-		gridData = new GridData();
-		gridData.horizontalSpan = 2;
-		gridData.horizontalAlignment = GridData.FILL;
-		gridData.grabExcessHorizontalSpace = true;
-		this.m_comboFailurePriority.setLayoutData(gridData);
-		this.m_comboFailurePriority.add(PriorityConstant.STRING_CRITICAL);
-		this.m_comboFailurePriority.add(PriorityConstant.STRING_WARNING);
-		this.m_comboFailurePriority.add(PriorityConstant.STRING_INFO);
-		this.m_comboFailurePriority.add(PriorityConstant.STRING_UNKNOWN);
-		this.m_comboFailurePriority.setText(PriorityConstant.STRING_UNKNOWN);
-		
-		// 空白
-        label = new Label(groupRunJob, SWT.NONE);
-        gridData = new GridData();
-        gridData.horizontalSpan = 2;
-        gridData.horizontalAlignment = GridData.FILL;
-        gridData.grabExcessHorizontalSpace = true;
-        label.setLayoutData(gridData);
         
         /*
          * 有効／無効
@@ -683,14 +520,30 @@ public class LogCreateDialog extends CommonDialog {
 
         // ログIDが指定されている場合、その情報を初期表示する。
         LogFilterInfo log = LogManager.getInstance().get(this.logId);
+        Collection<NotifyRelationInfo> modifyNotify = null;
+
         if (log == null) {
             log = new LogFilterInfo();
             modify = false;
         }
         else{
         	modify = true;
+        	
+        	// 通知関連情報のディープコピーを作成
+        	if(log.getNotifyId() != null) {
+	        	modifyNotify = new ArrayList<NotifyRelationInfo>();
+	        	Iterator<NotifyRelationInfo> itr = log.getNotifyId().iterator();
+	        	while(itr.hasNext()){
+	        		NotifyRelationInfo info = itr.next();
+	        		modifyNotify.add(new NotifyRelationInfo(
+	        				info.getNotifyGroupId(), 
+	        				info.getNotifyId(), 
+	        				info.getNotifyType(), 
+	        				info.getNotifyFlg()));
+	        	}
+        	}
         }
-        this.setInputData(log);
+        this.setInputData(log, modifyNotify);
     }
 
     /**
@@ -711,7 +564,7 @@ public class LogCreateDialog extends CommonDialog {
 	 * 
 	 * @see #setEnabledForOutputCondition(boolean)
      */
-    protected void setInputData(LogFilterInfo log) {
+    protected void setInputData(LogFilterInfo log, Collection<NotifyRelationInfo> modifyNotify) {
 
         this.inputData = log;
 
@@ -740,13 +593,20 @@ public class LogCreateDialog extends CommonDialog {
         } else {
             this.radioNotProcessing.setSelection(true);
         }
-        if (log.getNotifyId() != null) {
-            this.notifyInfo.setText(log.getNotifyId());
+  
+        //通知情報の設定
+//        if(log.getNotifyId() != null)
+//        	this.notifyInfo.setNotify(log.getNotifyId());
+        if(modifyNotify != null && modifyNotify.size() != 0){
+        	this.notifyInfo.setNotify(modifyNotify);
         }
-        this.comboPriority.setText(PriorityConstant.typeToString(log.getPriority()));
+        
+        //アプリケーション
         if (log.getApplication() != null) {
-            this.notifyInfo.setApplication(log.getApplication());
+        	this.notifyInfo.setApplication(log.getApplication());
         }
+        
+        this.comboPriority.setText(PriorityConstant.typeToString(log.getPriority()));
         if (log.getMessageId() != null) {
             this.textMessageId.setText(log.getMessageId());
         }
@@ -754,19 +614,12 @@ public class LogCreateDialog extends CommonDialog {
             this.textLogMessage.setText(log.getMessage());
         }
         
-        // ジョブ実行
-        this.m_checkJobRun.setSelection(YesNoConstant.typeToBoolean(log.getJobRun()));
-        if(log.getJobId() != null){
-			this.m_textJobId.setText(log.getJobId());
-		}
-		this.m_checkInhibitionFlg.setSelection(YesNoConstant.typeToBoolean(log.getJobInhibitionFlg()));
-		this.m_comboFailurePriority.setText(PriorityConstant.typeToString(log.getJobFailurePriority()));
-
-        if (log.isValidFlg() == ValidConstant.BOOLEAN_VALID) {
-            this.confirmValid.setSelection(true);
-        }
-        
         this.regDate = log.getRegDate();
+        
+		// 有効／無効
+		if (log.getValid() == ValidConstant.TYPE_VALID) {
+			this.confirmValid.setSelection(true);
+		}
 
         // 入力制御
         this.setEnabledForOutputCondition(this.radioProcessing.getSelection());
@@ -830,7 +683,7 @@ public class LogCreateDialog extends CommonDialog {
     		}
     		catch(PatternSyntaxException e){
     			this.setValidateResult(Messages.getString("message.hinemos.1"),
-                        Messages.getString("message.monitor.27"));
+                        Messages.getString("message.monitor.55"));
                 return null;
     		}
             
@@ -848,73 +701,59 @@ public class LogCreateDialog extends CommonDialog {
         String priorityText = this.comboPriority.getText();
         log.setPriority(PriorityConstant.stringToType(priorityText));
         
-        // 通知ID
-        String notifyId = this.notifyInfo.getText();
-        if (notifyId != null && !"".equals(notifyId.trim())) {
-        	log.setNotifyId(notifyId);
-        }
         
-        if (this.notifyInfo.getApplication() != null
-                && !"".equals((this.notifyInfo.getApplication()).trim())) {
-            log.setApplication(this.notifyInfo.getApplication());
-        } else {
-            if (this.radioProcessing.getSelection()) {
-            	if (notifyId != null && !"".equals(notifyId.trim())) {
-            		this.setValidateResult(Messages.getString("message.hinemos.1"),
-                            Messages.getString("message.monitor.10"));
-                    return null;
-            	}
-            }
-        }
-
+        
+        // 通知関連情報の設定
+        boolean isSetNotifyId = true;
+		// 通知グループIDの設定
+		log.setNotifyGroupId(NotifyRelationInfo.createNotifyGroupId(
+				HinemosModuleConstant.MONITOR_SYSLOGNG, log.getMonitorId()));
+		validateResult = notifyInfo.createInputData(log);
+		if (this.radioProcessing.getSelection() && validateResult != null) {
+			if(validateResult.getID() == null){	// 通知ID警告用出力
+				if(!displayQuestion(validateResult)){
+					validateResult = null;
+					return null;
+				}
+				else {
+					isSetNotifyId = false;
+				}
+			}
+			else{	// アプリケーション未入力チェック
+				return null;
+			}
+		} 
+		
+		// メッセージIDの設定
         if (this.textMessageId.getText() != null
                 && !"".equals((this.textMessageId.getText()).trim())) {
             log.setMessageId(this.textMessageId.getText());
         } else {
-            if (this.radioProcessing.getSelection()) {
-            	if (notifyId != null && !"".equals(notifyId.trim())) {
-            		this.setValidateResult(Messages.getString("message.hinemos.1"),
-                            Messages.getString("message.monitor.28"));
-                    return null;	
-            	}
+            if (this.radioProcessing.getSelection() && isSetNotifyId) {
+            	this.setValidateResult(Messages.getString("message.hinemos.1"),
+                        Messages.getString("message.monitor.28"));
+            	return null;
             }
         }
+        
+        // メッセージの設定
         if (this.textLogMessage.getText() != null
                 && !"".equals((this.textLogMessage.getText()).trim())) {
             log.setMessage(this.textLogMessage.getText());
         } else {
-            if (this.radioProcessing.getSelection()) {
-            	if (notifyId != null && !"".equals(notifyId.trim())) {
-            		this.setValidateResult(Messages.getString("message.hinemos.1"),
-                            Messages.getString("message.monitor.29"));
-                    return null;	
-            	}
+            if (this.radioProcessing.getSelection() && isSetNotifyId) {
+            	this.setValidateResult(Messages.getString("message.hinemos.1"),
+                        Messages.getString("message.monitor.29"));
+            	return null;
             }
         }
         
-        // ジョブ実行
-		log.setJobRun(Integer.valueOf(YesNoConstant.booleanToType(m_checkJobRun.getSelection())));
-		// ジョブID
-		if (m_textJobId.getText() != null && !"".equals(m_textJobId.getText().trim())) {
-			log.setJobId(m_textJobId.getText());	
-		}
-		else{
-			if(log.getJobRun() == YesNoConstant.TYPE_YES){
-				String[] args = {""};
-				this.setValidateResult(Messages.getString("message.hinemos.1"),Messages.getString("message.monitor.25", args));
-				return null;
-			}
-		}
-		// 通知抑制と連動
-		log.setJobInhibitionFlg(Integer.valueOf(YesNoConstant.booleanToType(m_checkInhibitionFlg.getSelection())));
-		// 呼出失敗時
-		log.setJobFailurePriority(PriorityConstant.stringToType(m_comboFailurePriority.getText()));
-        
+     
         // 有効
         if (this.confirmValid.getSelection()) {
-            log.setValidFlg(ValidConstant.BOOLEAN_VALID);
+            log.setValid(ValidConstant.TYPE_VALID);
         } else {
-            log.setValidFlg(ValidConstant.BOOLEAN_INVALID);
+            log.setValid(ValidConstant.TYPE_INVALID);
         }
         
         // 登録日時
@@ -998,11 +837,6 @@ public class LogCreateDialog extends CommonDialog {
         this.notifyInfo.setEnabled(enable);
         this.textMessageId.setEnabled(enable);
         this.textLogMessage.setEnabled(enable);
-        this.m_checkJobRun.setEnabled(enable);
-        this.m_textJobId.setEnabled(enable);
-        this.m_buttonRefer.setEnabled(enable);
-        this.m_checkInhibitionFlg.setEnabled(enable);
-        this.m_comboFailurePriority.setEnabled(enable);
     }
     
     /**
@@ -1018,4 +852,5 @@ public class LogCreateDialog extends CommonDialog {
         this.validateResult.setID(id);
         this.validateResult.setMessage(message);
     }
+    
 }
\ No newline at end of file
